"""
ABSDATASET
---
"""

__title__ = "absdataset"
__license__ = "MIT License"
__version__ = "1.1.0"

from .pkg_data import *